@@ -24,6 +24,8 @@
 #' @param targetCohortId vector of cohort definition ids to include
 #' @param indexDate Variable in x that contains the date to compute the
 #' intersection.
+#' @param censorDate whether to censor overlap events at a specific date
+#' or a column date of x
 #' @param targetStartDate date of reference in cohort table, either for start
 #' (in overlap) or on its own (for incidence)
 #' @param targetEndDate date of reference in cohort table, either for end
@@ -102,17 +104,17 @@
 #'
 #' result <- cdm$cohort1 %>%
 #'   addCohortIntersect(
-#'     cdm = cdm,
 #'     targetCohortTable = "cohort2"
 #'   ) %>%
 #'   dplyr::collect()
 #' }
 #'
 addCohortIntersect <- function(x,
-                               cdm,
+                               cdm = attr(x, "cdm_reference"),
                                targetCohortTable,
                                targetCohortId = NULL,
                                indexDate = "cohort_start_date",
+                               censorDate = NULL,
                                targetStartDate = "cohort_start_date",
                                targetEndDate = "cohort_end_date",
                                window = list(c(0, Inf)),
@@ -148,6 +150,7 @@ addCohortIntersect <- function(x,
       window = window,
       order = order,
       nameStyle = nameStyle,
+      censorDate = censorDate,
       tablePrefix = tablePrefix
     )
 
@@ -163,6 +166,8 @@ addCohortIntersect <- function(x,
 #' @param targetCohortId vector of cohort definition ids to include
 #' @param indexDate Variable in x that contains the date to compute the
 #' intersection.
+#' @param censorDate whether to censor overlap events at a specific date
+#' or a column date of x
 #' @param targetStartDate date of reference in cohort table, either for start
 #' (in overlap) or on its own (for incidence)
 #' @param targetEndDate date of reference in cohort table, either for end
@@ -232,17 +237,17 @@ addCohortIntersect <- function(x,
 #'
 #' result <- cdm$cohort1 %>%
 #'   addCohortIntersectFlag(
-#'     cdm = cdm,
 #'     targetCohortTable = "cohort2"
 #'   ) %>%
 #'   dplyr::collect()
 #' }
 #'
 addCohortIntersectFlag <- function(x,
-                                   cdm,
+                                   cdm = attr(x, "cdm_reference"),
                                    targetCohortTable,
                                    targetCohortId = NULL,
                                    indexDate = "cohort_start_date",
+                                   censorDate = NULL,
                                    targetStartDate = "cohort_start_date",
                                    targetEndDate = "cohort_end_date",
                                    window = list(c(0, Inf)),
@@ -266,6 +271,7 @@ addCohortIntersectFlag <- function(x,
       targetEndDate = targetEndDate,
       window = window,
       nameStyle = nameStyle,
+      censorDate = censorDate,
       tablePrefix = tablePrefix
     )
 
@@ -282,6 +288,8 @@ addCohortIntersectFlag <- function(x,
 #' @param targetCohortId vector of cohort definition ids to include
 #' @param indexDate Variable in x that contains the date to compute the
 #' intersection.
+#' @param censorDate whether to censor overlap events at a specific date
+#' or a column date of x
 #' @param targetStartDate date of reference in cohort table, either for start
 #' (in overlap) or on its own (for incidence)
 #' @param targetEndDate date of reference in cohort table, either for end
@@ -354,17 +362,17 @@ addCohortIntersectFlag <- function(x,
 #'
 #' result <- cdm$cohort1 %>%
 #'   addCohortIntersectCount(
-#'     cdm = cdm,
 #'     targetCohortTable = "cohort2"
 #'   ) %>%
 #'   dplyr::collect()
 #' }
 #'
 addCohortIntersectCount <- function(x,
-                                    cdm,
+                                    cdm = attr(x, "cdm_reference"),
                                     targetCohortTable,
                                     targetCohortId = NULL,
                                     indexDate = "cohort_start_date",
+                                    censorDate = NULL,
                                     targetStartDate = "cohort_start_date",
                                     targetEndDate = "cohort_end_date",
                                     window = list(c(0, Inf)),
@@ -388,6 +396,7 @@ addCohortIntersectCount <- function(x,
       targetEndDate = targetEndDate,
       window = window,
       nameStyle = nameStyle,
+      censorDate = censorDate,
       tablePrefix = tablePrefix
     )
 
@@ -406,6 +415,8 @@ addCohortIntersectCount <- function(x,
 #' cohort of interest
 #' @param indexDate Variable in x that contains the date to compute the
 #' intersection.
+#' @param censorDate whether to censor overlap events at a specific date
+#' or a column date of x
 #' @param targetDate Date of interest in the other cohort table. Either
 #' cohort_start_date or cohort_end_date
 #' @param order date to use if there are multiple records for an
@@ -479,17 +490,17 @@ addCohortIntersectCount <- function(x,
 #'
 #' result <- cdm$cohort1 %>%
 #'   addCohortIntersectDays(
-#'     cdm = cdm,
 #'     targetCohortTable = "cohort2"
 #'   ) %>%
 #'   dplyr::collect()
 #' }
 #'
 addCohortIntersectDays <- function(x,
-                                   cdm,
+                                   cdm = attr(x, "cdm_reference"),
                                    targetCohortTable,
                                    targetCohortId = NULL,
                                    indexDate = "cohort_start_date",
+                                   censorDate = NULL,
                                    targetDate = "cohort_start_date",
                                    order = "first",
                                    window = c(0, Inf),
@@ -514,6 +525,7 @@ addCohortIntersectDays <- function(x,
       targetEndDate = NULL,
       order = order,
       nameStyle = nameStyle,
+      censorDate = censorDate,
       tablePrefix = tablePrefix
     )
 
@@ -532,6 +544,8 @@ addCohortIntersectDays <- function(x,
 #' cohort of interest
 #' @param indexDate Variable in x that contains the date to compute the
 #' intersection.
+#' @param censorDate whether to censor overlap events at a specific date
+#' or a column date of x
 #' @param targetDate Date of interest in the other cohort table. Either
 #' cohort_start_date or cohort_end_date
 #' @param order date to use if there are multiple records for an
@@ -605,17 +619,17 @@ addCohortIntersectDays <- function(x,
 #'
 #' result <- cdm$cohort1 %>%
 #'   addCohortIntersectDate(
-#'     cdm = cdm,
 #'     targetCohortTable = "cohort2"
 #'   ) %>%
 #'   dplyr::collect()
 #' }
 #'
 addCohortIntersectDate <- function(x,
-                                   cdm,
+                                   cdm = attr(x, "cdm_reference"),
                                    targetCohortTable,
                                    targetCohortId = NULL,
                                    indexDate = "cohort_start_date",
+                                   censorDate = NULL,
                                    targetDate = "cohort_start_date",
                                    order = "first",
                                    window = c(0, Inf),
@@ -640,6 +654,7 @@ addCohortIntersectDate <- function(x,
       targetEndDate = NULL,
       order = order,
       nameStyle = nameStyle,
+      censorDate = censorDate,
       tablePrefix = tablePrefix
     )
 
