@@ -7,7 +7,6 @@ test_that("output format - one outcome cohort", {
 
   cdm$cohort1a <- cdm$cohort1 %>%
     addCohortIntersectDays(
-      cdm = cdm,
       targetCohortId = 1,
       targetDate = "cohort_start_date",
       targetCohortTable = "cohort2"
@@ -16,7 +15,6 @@ test_that("output format - one outcome cohort", {
 
   cdm$cohort1b <- cdm$cohort1 %>%
     addCohortIntersectDate(
-      cdm = cdm,
       targetCohortId = 1,
       targetDate = "cohort_start_date",
       targetCohortTable = "cohort2"
@@ -30,7 +28,6 @@ test_that("output format - one outcome cohort", {
   # In 0 to Inf - 2 target cohorts have someone
   cdm$cohort1a <- cdm$cohort1 %>%
     addCohortIntersectDays(
-      cdm = cdm,
       window = c(0, Inf),
       targetCohortId = NULL,
       indexDate = "cohort_start_date",
@@ -39,7 +36,6 @@ test_that("output format - one outcome cohort", {
   expect_true(ncol(cdm$cohort1a) == 7)
   cdm$cohort1b <- cdm$cohort1 %>%
     addCohortIntersectDate(
-      cdm = cdm,
       window = c(0, Inf),
       targetCohortId = NULL,
       indexDate = "cohort_start_date",
@@ -50,7 +46,6 @@ test_that("output format - one outcome cohort", {
   # In -Inf to Inf - 2 target cohorts have someone
   cdm$cohort1c <- cdm$cohort1 %>%
     addCohortIntersectDays(
-      cdm = cdm,
       window = c(-Inf, Inf),
       targetCohortId = NULL,
       indexDate = "cohort_start_date",
@@ -59,7 +54,6 @@ test_that("output format - one outcome cohort", {
   expect_true(ncol(cdm$cohort1c) == 7)
   cdm$cohort1d <- cdm$cohort1 %>%
     addCohortIntersectDate(
-      cdm = cdm,
       window = c(-Inf, Inf),
       targetCohortId = NULL,
       indexDate = "cohort_start_date",
@@ -105,88 +99,85 @@ test_that("first vs last event - cohort table", {
   cdm <- mockPatientProfiles(
     connectionDetails,
     cohort1 = cohort1,
-    cohort2 = cohort2
+    cohort2 = cohort2,
+    patient_size = 2
   )
 
   # first
   cdm$cohort1a <- cdm$cohort1 %>%
     addCohortIntersectDays(
-      cdm = cdm,
       targetCohortId = 1,
       indexDate = "cohort_start_date",
       targetCohortTable = "cohort2",
       order = "first"
     )
   expect_true(cdm$cohort1a %>%
-    dplyr::filter(subject_id == 1) %>%
-    dplyr::pull(5) ==
-    as.numeric(difftime(as.Date("2010-03-03"),
-      as.Date("2010-03-01"),
-      units = "days"
-    )))
+                dplyr::filter(subject_id == 1) %>%
+                dplyr::pull(5) ==
+                as.numeric(difftime(as.Date("2010-03-03"),
+                                    as.Date("2010-03-01"),
+                                    units = "days"
+                )))
   expect_true(cdm$cohort1a %>%
-    dplyr::filter(subject_id == 2) %>%
-    dplyr::pull(5) ==
-    as.numeric(difftime(as.Date("2013-01-03"),
-      as.Date("2011-02-01"),
-      units = "days"
-    )))
+                dplyr::filter(subject_id == 2) %>%
+                dplyr::pull(5) ==
+                as.numeric(difftime(as.Date("2013-01-03"),
+                                    as.Date("2011-02-01"),
+                                    units = "days"
+                )))
 
   cdm$cohort1b <- cdm$cohort1 %>%
     addCohortIntersectDate(
-      cdm = cdm,
       targetCohortId = 1,
       indexDate = "cohort_start_date",
       targetCohortTable = "cohort2",
       order = "first"
     )
   expect_true(cdm$cohort1b %>%
-    dplyr::filter(subject_id == 1) %>%
-    dplyr::pull(5) == as.Date("2010-03-03"))
+                dplyr::filter(subject_id == 1) %>%
+                dplyr::pull(5) == as.Date("2010-03-03"))
   expect_true(cdm$cohort1b %>%
-    dplyr::filter(subject_id == 2) %>%
-    dplyr::pull(5) == as.Date("2013-01-03"))
+                dplyr::filter(subject_id == 2) %>%
+                dplyr::pull(5) == as.Date("2013-01-03"))
 
 
   # last
   cdm$cohort1c <- cdm$cohort1 %>%
     addCohortIntersectDays(
-      cdm = cdm,
       targetCohortId = 1,
       indexDate = "cohort_start_date",
       targetCohortTable = "cohort2",
       order = "last"
     )
   expect_true(cdm$cohort1c %>%
-    dplyr::filter(subject_id == 1) %>%
-    dplyr::pull(5) ==
-    as.numeric(difftime(as.Date("2010-03-25"),
-      as.Date("2010-03-01"),
-      units = "days"
-    )))
+                dplyr::filter(subject_id == 1) %>%
+                dplyr::pull(5) ==
+                as.numeric(difftime(as.Date("2010-03-25"),
+                                    as.Date("2010-03-01"),
+                                    units = "days"
+                )))
   expect_true(cdm$cohort1c %>%
-    dplyr::filter(subject_id == 2) %>%
-    dplyr::pull(5) ==
-    as.numeric(difftime(as.Date("2013-01-03"),
-      as.Date("2011-02-01"),
-      units = "days"
-    )))
+                dplyr::filter(subject_id == 2) %>%
+                dplyr::pull(5) ==
+                as.numeric(difftime(as.Date("2013-01-03"),
+                                    as.Date("2011-02-01"),
+                                    units = "days"
+                )))
 
   cdm$cohort1d <- cdm$cohort1 %>%
     addCohortIntersectDate(
-      cdm = cdm,
       targetCohortId = 1,
       indexDate = "cohort_start_date",
       targetCohortTable = "cohort2",
       order = "last"
     )
   expect_true(cdm$cohort1d %>%
-    dplyr::filter(subject_id == 1) %>%
-    dplyr::pull(5) ==
-    as.Date("2010-03-25"))
+                dplyr::filter(subject_id == 1) %>%
+                dplyr::pull(5) ==
+                as.Date("2010-03-25"))
   expect_true(cdm$cohort1d %>%
-    dplyr::filter(subject_id == 2) %>%
-    dplyr::pull(5) == as.Date("2013-01-03"))
+                dplyr::filter(subject_id == 2) %>%
+                dplyr::pull(5) == as.Date("2013-01-03"))
 })
 
 test_that("multiple cohort entries per person", {
@@ -228,13 +219,13 @@ test_that("multiple cohort entries per person", {
   cdm <- mockPatientProfiles(
     connectionDetails,
     cohort1 = cohort1,
-    cohort2 = cohort2
+    cohort2 = cohort2,
+    patient_size = 2
   )
 
   # 100 days from index
   cdm$cohort1a <- cdm$cohort1 %>%
     addCohortIntersectDays(
-      cdm = cdm,
       window = c(0, 100),
       indexDate = "cohort_start_date",
       targetCohortTable = "cohort2",
@@ -242,19 +233,19 @@ test_that("multiple cohort entries per person", {
     )
 
   expect_true(all(cdm$cohort1a %>%
-    dplyr::filter(subject_id == 1) %>%
-    dplyr::arrange(cohort_start_date) %>%
-    dplyr::pull(5) ==
-    c(
-      as.numeric(difftime(as.Date("2010-03-03"),
-        as.Date("2010-03-01"),
-        units = "days"
-      )),
-      as.numeric(difftime(as.Date("2012-03-25"),
-        as.Date("2012-03-01"),
-        units = "days"
-      ))
-    )))
+                    dplyr::filter(subject_id == 1) %>%
+                    dplyr::arrange(cohort_start_date) %>%
+                    dplyr::pull(5) ==
+                    c(
+                      as.numeric(difftime(as.Date("2010-03-03"),
+                                          as.Date("2010-03-01"),
+                                          units = "days"
+                      )),
+                      as.numeric(difftime(as.Date("2012-03-25"),
+                                          as.Date("2012-03-01"),
+                                          units = "days"
+                      ))
+                    )))
 
   expect_equal(
     cdm$cohort1 %>% dplyr::tally() %>% dplyr::pull("n"),
@@ -263,7 +254,6 @@ test_that("multiple cohort entries per person", {
 
   cdm$cohort1b <- cdm$cohort1 %>%
     addCohortIntersectDate(
-      cdm = cdm,
       window = c(0, 100),
       indexDate = "cohort_start_date",
       targetCohortTable = "cohort2",
@@ -271,13 +261,13 @@ test_that("multiple cohort entries per person", {
     )
 
   expect_true(all(cdm$cohort1b %>%
-    dplyr::filter(subject_id == 1) %>%
-    dplyr::arrange(cohort_start_date) %>%
-    dplyr::pull(5) ==
-    c(
-      as.Date("2010-03-03"),
-      as.Date("2012-03-25")
-    )))
+                    dplyr::filter(subject_id == 1) %>%
+                    dplyr::arrange(cohort_start_date) %>%
+                    dplyr::pull(5) ==
+                    c(
+                      as.Date("2010-03-03"),
+                      as.Date("2012-03-25")
+                    )))
 
   expect_equal(
     cdm$cohort1 %>% dplyr::tally() %>% dplyr::pull("n"),
@@ -294,7 +284,6 @@ test_that("output names", {
   # default naming
   cdm$cohort1a <- cdm$cohort1 %>%
     addCohortIntersectDays(
-      cdm = cdm,
       window = c(10, 50),
       targetCohortId = NULL,
       targetDate = "cohort_start_date",
@@ -309,7 +298,6 @@ test_that("output names", {
 
   cdm$cohort1b <- cdm$cohort1 %>%
     addCohortIntersectDate(
-      cdm = cdm,
       window = c(10, 50),
       targetCohortId = NULL,
       targetDate = "cohort_start_date",
@@ -325,7 +313,6 @@ test_that("output names", {
   # new names
   cdm$cohort1c <- cdm$cohort1 %>%
     addCohortIntersectDays(
-      cdm = cdm,
       window = c(10, 50),
       targetCohortId = NULL,
       targetDate = "cohort_start_date",
@@ -342,7 +329,6 @@ test_that("output names", {
   # new names
   cdm$cohort1d <- cdm$cohort1 %>%
     addCohortIntersectDate(
-      cdm = cdm,
       window = c(10, 50),
       targetCohortId = NULL,
       targetDate = "cohort_start_date",
@@ -355,6 +341,17 @@ test_that("output names", {
     "study_cohort_3"
   ) %in%
     colnames(cdm$cohort1c)))
+
+  # bad naming
+  expect_error(cdm$cohort1 %>%
+                 addCohortIntersectDate(
+                   window = list(c(0,3),c(10, 50)),
+                   targetCohortId = NULL,
+                   targetDate = "cohort_start_date",
+                   targetCohortTable = "cohort2",
+                   nameStyle = "study")
+  )
+
 })
 
 test_that("expected errors ", {
@@ -362,43 +359,57 @@ test_that("expected errors ", {
 
   # not a cdm
   expect_error(cdm$cohort1 %>%
-    addCohortIntersectDays(
-      cdm = "a",
-      targetCohortId = 1,
-      indexDate = "cohort_start_date",
-      targetCohortTable = "cohort2"
-    ))
+                 addCohortIntersectDays(
+                   cdm = "a",
+                   targetCohortId = 1,
+                   indexDate = "cohort_start_date",
+                   targetCohortTable = "cohort2"
+                 ))
   expect_error(cdm$cohort1 %>%
-    addCohortIntersectDate(
-      cdm = "a",
-      targetCohortId = 1,
-      indexDate = "cohort_start_date",
-      targetCohortTable = "cohort2"
-    ))
+                 addCohortIntersectDate(
+                   cdm = "a",
+                   targetCohortId = 1,
+                   indexDate = "cohort_start_date",
+                   targetCohortTable = "cohort2"
+                 ))
 
   # missing outcome table
   expect_error(cdm$cohort1 %>%
-    addCohortIntersectDays(
-      cdm = cdm,
-      targetCohortId = 1,
-      indexDate = "cohort_start_date",
-      targetCohortTable = "table_x"
-    ))
+                 addCohortIntersectDays(
+                   targetCohortId = 1,
+                   indexDate = "cohort_start_date",
+                   targetCohortTable = "table_x"
+                 ))
   expect_error(cdm$cohort1 %>%
-    addCohortIntersectDate(
-      cdm = cdm,
-      targetCohortId = 1,
-      indexDate = "cohort_start_date",
-      targetCohortTable = "table_x"
-    ))
+                 addCohortIntersectDate(
+                   targetCohortId = 1,
+                   indexDate = "cohort_start_date",
+                   targetCohortTable = "table_x"
+                 ))
+
+  expect_error(cdm$cohort1 %>%
+                 addCohortIntersectDays(
+                   targetCohortId = 1,
+                                        indexDate = "cohort_start_date",
+                                        targetCohortTable = "cohort2",
+                                        window = c(300, 100)))
+
+  expect_error(cdm$cohort1 %>%
+                 addCohortIntersectDate(
+                   targetCohortId = 1,
+                   indexDate = "cohort_start_date",
+                   targetCohortTable = "cohort2",
+                   censorDate = as.Date("2020-01-01")
+                 ))
+
+  expect_error(cdm$cohort1 %>%
+                 addCohortIntersectDate(
+                   targetCohortId = 1,
+                   indexDate = "cohort_start_date",
+                   targetCohortTable = "cohort2",
+                   censorDate ="subject_id"
+                 ))
 
-  # unreasonable window
-  # expect_error(cdm$cohort1 %>%
-  #                addCohortIntersectDays(cdm = cdm,
-  #                            targetCohortId = 1,
-  #                            indexDate = "cohort_start_date",
-  #                            targetCohortTable = "cohort2",
-  #                            window = c(300, 100)))
 })
 
 test_that("working examples", {
@@ -453,22 +464,25 @@ test_that("working examples", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails,
+                             cohort1 = cohort1,
+                             cohort2 = cohort2,
+                             patient_size = 2)
 
   result0 <- cdm$cohort1 %>%
-    addCohortIntersectCount(cdm = cdm, targetCohortTable = "cohort2") %>%
+    addCohortIntersectCount(targetCohortTable = "cohort2") %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
   result1 <- cdm$cohort1 %>%
-    addCohortIntersectCount(cdm = cdm, targetCohortTable = "cohort2", targetCohortId = 1) %>%
+    addCohortIntersectCount(targetCohortTable = "cohort2", targetCohortId = 1) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
   result2 <- cdm$cohort1 %>%
-    addCohortIntersectCount(cdm = cdm, targetCohortTable = "cohort2", targetCohortId = 2) %>%
+    addCohortIntersectCount(targetCohortTable = "cohort2", targetCohortId = 2) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
   result3 <- cdm$cohort1 %>%
-    addCohortIntersectCount(cdm = cdm, targetCohortTable = "cohort2", targetCohortId = 3) %>%
+    addCohortIntersectCount(targetCohortTable = "cohort2", targetCohortId = 3) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
@@ -478,7 +492,7 @@ test_that("working examples", {
 
   result1 <- cdm$cohort1 %>%
     addCohortIntersectCount(
-      cdm = cdm, targetCohortTable = "cohort2", targetCohortId = c(2, 3),
+      targetCohortTable = "cohort2", targetCohortId = c(2, 3),
       window = list(c(-Inf, 0))
     ) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
@@ -493,7 +507,7 @@ test_that("working examples", {
   )
   result2 <- cdm$cohort1 %>%
     addCohortIntersectCount(
-      cdm = cdm, targetCohortTable = "cohort2", targetCohortId = c(2, 3),
+      targetCohortTable = "cohort2", targetCohortId = c(2, 3),
       window = list(c(-Inf, 0))
     ) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
@@ -555,22 +569,25 @@ test_that("working examples", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails,
+                             cohort1 = cohort1,
+                             cohort2 = cohort2,
+                             patient_size = 2)
 
   result0 <- cdm$cohort1 %>%
-    addCohortIntersectFlag(cdm = cdm, targetCohortTable = "cohort2") %>%
+    addCohortIntersectFlag(targetCohortTable = "cohort2") %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
   result1 <- cdm$cohort1 %>%
-    addCohortIntersectFlag(cdm = cdm, targetCohortTable = "cohort2", targetCohortId = 1) %>%
+    addCohortIntersectFlag(targetCohortTable = "cohort2", targetCohortId = 1) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
   result2 <- cdm$cohort1 %>%
-    addCohortIntersectFlag(cdm = cdm, targetCohortTable = "cohort2", targetCohortId = 2) %>%
+    addCohortIntersectFlag(targetCohortTable = "cohort2", targetCohortId = 2) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
   result3 <- cdm$cohort1 %>%
-    addCohortIntersectFlag(cdm = cdm, targetCohortTable = "cohort2", targetCohortId = 3) %>%
+    addCohortIntersectFlag(targetCohortTable = "cohort2", targetCohortId = 3) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
@@ -579,7 +596,7 @@ test_that("working examples", {
   expect_true(all(result0$cohort_3_0_to_inf == result3$cohort_3_0_to_inf))
 
   result1 <- cdm$cohort1 %>%
-    addCohortIntersectFlag(cdm = cdm, targetCohortTable = "cohort2", targetCohortId = 2) %>%
+    addCohortIntersectFlag(targetCohortTable = "cohort2", targetCohortId = 2) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
@@ -638,18 +655,21 @@ test_that("working examples", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails,
+                             cohort1 = cohort1,
+                             cohort2 = cohort2,
+                             patient_size = 2)
 
   result1 <- cdm$cohort1 %>%
-    addCohortIntersect(cdm = cdm, targetCohortTable = "cohort2") %>%
+    addCohortIntersect(targetCohortTable = "cohort2") %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
   result2 <- cdm$cohort1 %>%
-    addCohortIntersectCount(cdm = cdm, targetCohortTable = "cohort2", nameStyle = "{value}_{cohort_name}_{window_name}") %>%
-    addCohortIntersectFlag(cdm = cdm, targetCohortTable = "cohort2", nameStyle = "{value}_{cohort_name}_{window_name}") %>%
-    addCohortIntersectDate(cdm = cdm, targetCohortTable = "cohort2", nameStyle = "{value}_{cohort_name}_{window_name}") %>%
-    addCohortIntersectDays(cdm = cdm, targetCohortTable = "cohort2", nameStyle = "{value}_{cohort_name}_{window_name}") %>%
+    addCohortIntersectCount(targetCohortTable = "cohort2", nameStyle = "{value}_{cohort_name}_{window_name}") %>%
+    addCohortIntersectFlag(targetCohortTable = "cohort2", nameStyle = "{value}_{cohort_name}_{window_name}") %>%
+    addCohortIntersectDate(targetCohortTable = "cohort2", nameStyle = "{value}_{cohort_name}_{window_name}") %>%
+    addCohortIntersectDays(targetCohortTable = "cohort2", nameStyle = "{value}_{cohort_name}_{window_name}") %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
@@ -661,3 +681,85 @@ test_that("working examples", {
     expect_true(all(x == y))
   }
 })
+
+test_that("censorDate functionality", {
+  cohort1 <- dplyr::tibble(
+    cohort_definition_id = c(1, 1, 1, 1, 1),
+    subject_id = c(1, 2, 3, 4, 5),
+    cohort_start_date = as.Date(
+      c(
+        "2020-01-01",
+        "2020-01-15",
+        "2020-01-20",
+        "2020-01-01",
+        "2020-02-01"
+      )
+    ),
+    cohort_end_date = as.Date(
+      c(
+        "2020-03-01",
+        "2021-01-15",
+        "2022-01-20",
+        "2020-01-06",
+        "2020-07-01"
+      )
+    )
+  )
+
+  cohort2 <- dplyr::tibble(
+    cohort_definition_id = c(1, 1, 1, 1, 1, 1, 1),
+    subject_id = c(1, 1, 2, 3, 4, 5, 5),
+    cohort_start_date = as.Date(
+      c(
+        "2020-01-15",
+        "2020-01-25",
+        "2020-01-26",
+        "2020-01-29",
+        "2020-03-15",
+        "2020-01-24",
+        "2020-02-16"
+      )
+    ),
+    cohort_end_date = as.Date(
+      c(
+        "2020-01-15",
+        "2020-01-25",
+        "2020-01-26",
+        "2020-01-29",
+        "2020-03-15",
+        "2020-01-24",
+        "2020-02-16"
+      )
+    ),
+  )
+
+  cdm <- mockPatientProfiles(connectionDetails,
+                             cohort1 = cohort1,
+                             cohort2 = cohort2,
+                             patient_size = 5)
+
+  compareNA <- function(v1, v2) {
+    same <- (v1 == v2) | (is.na(v1) & is.na(v2))
+    same[is.na(same)] <- FALSE
+    return(same)
+  }
+
+  result1 <- cdm$cohort1 %>%
+    addCohortIntersect(targetCohortTable = "cohort2") %>%
+    dplyr::arrange(subject_id, cohort_start_date) %>%
+    dplyr::collect()
+
+  result2 <- cdm$cohort1 %>%
+    addCohortIntersect(targetCohortTable = "cohort2", censorDate = "cohort_end_date") %>%
+    dplyr::arrange(subject_id, cohort_start_date) %>%
+    dplyr::collect()
+
+  expect_true(all(result1 %>% dplyr::filter(subject_id != 4) %>% dplyr::arrange("cohort_start_date") %>% dplyr::select(order(colnames(result1))) ==
+                    result2 %>% dplyr::filter(subject_id != 4) %>% dplyr::arrange("cohort_start_date") %>% dplyr::select(order(colnames(result2)))))
+  expect_true(all(compareNA(result2 %>% dplyr::filter(subject_id == 4) %>%
+                              dplyr::select(dplyr::ends_with("inf")) %>% dplyr::arrange("subject_id") %>%
+                              unlist(use.names = F),
+                            c(0,0,NA,NA))))
+
+})
+
