@@ -50,7 +50,7 @@ test_that("working examples", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2, patient_size = 2)
 
   result <- cdm$cohort1 %>%
     addIntersect(cdm = cdm, tableName = "cohort2", value = "date", nameStyle = "xx") %>%
@@ -241,7 +241,7 @@ test_that("working examples with cohort_end_date", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2, patient_size = 2)
 
   result <- cdm$cohort1 %>%
     addIntersect(
@@ -306,7 +306,7 @@ test_that("working examples with extra column", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2, patient_size = 2)
 
   cdm$cohort2 <- cdm$cohort2 %>%
     dbplyr::window_order(
@@ -355,7 +355,7 @@ test_that("working examples with extra column", {
 
 
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2, patient_size = 2)
 
   cdm$cohort2 <- cdm$cohort2 %>%
     dbplyr::window_order(
@@ -367,15 +367,15 @@ test_that("working examples with extra column", {
 
   result2 <- cdm$cohort1 %>%
     addIntersect(cdm, "cohort2", "measurment_result",
-      nameStyle = "{value}_{window_name}"
+                 nameStyle = "{value}_{window_name}"
     ) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
   result3 <- cdm$cohort1 %>%
     addIntersect(cdm, "cohort2", c("flag", "measurment_result"),
-      nameStyle = "{value}_{window_name}",
-      window = list(c(-400, -200))
+                 nameStyle = "{value}_{window_name}",
+                 window = list(c(-400, -200))
     ) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
@@ -438,7 +438,7 @@ test_that("working examples with multiple cohort Ids", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2, patient_size = 2)
 
   compareNA <- function(v1, v2) {
     same <- (v1 == v2) | (is.na(v1) & is.na(v2))
@@ -608,7 +608,7 @@ test_that("working examples with more than one window", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2, patient_size = 2)
 
   compareNA <- function(v1, v2) {
     same <- (v1 == v2) | (is.na(v1) & is.na(v2))
@@ -692,7 +692,7 @@ test_that("working examples with tables, not cohorts", {
   cdm <- mockPatientProfiles(connectionDetails,
                              cohort1 = cohort1,
                              condition_occurrence = conditionOccurrence,
-                             drug_exposure = drugExposure)
+                             drug_exposure = drugExposure, patient_size = 2)
 
   compareNA <- function(v1, v2) {
     same <- (v1 == v2) | (is.na(v1) & is.na(v2))
@@ -819,7 +819,7 @@ test_that("check input length and type for each of the arguments", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2, patient_size = 2)
 
   expect_error(addIntersect("cdm$cohort1", cdm))
 
@@ -844,14 +844,14 @@ test_that("test checkWindow function", {
   cdm <- mockPatientProfiles(connectionDetails)
 
   expect_error(cdm$cohort1 %>%
-    addIntersect(
-      cdm = cdm,
-      value = "days",
-      filterId = 1,
-      filterVariable = "cohort_definition_id",
-      tableName = "cohort2",
-      window = c(150, -90)
-    ))
+                 addIntersect(
+                   cdm = cdm,
+                   value = "days",
+                   filterId = 1,
+                   filterVariable = "cohort_definition_id",
+                   tableName = "cohort2",
+                   window = c(150, -90)
+                 ))
 })
 
 test_that("test if column exist, overwrite", {
@@ -909,7 +909,7 @@ test_that("test if column exist, overwrite", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2, patient_size = 2)
 
   result <- cdm$cohort1 %>%
     addIntersect(
@@ -920,28 +920,28 @@ test_that("test if column exist, overwrite", {
 
   expect_true(sum(colnames(result) == "flag_all_0_to_30") == 1)
   expect_true(all(result %>% dplyr::arrange(cohort_start_date, subject_id) %>%
-    dplyr::select(flag_all_0_to_30) !=
-    cohort1 %>%
-      dplyr::arrange(cohort_start_date, subject_id) %>%
-      dplyr::select(flag_all_0_to_30), na.rm = TRUE))
+                    dplyr::select(flag_all_0_to_30) !=
+                    cohort1 %>%
+                    dplyr::arrange(cohort_start_date, subject_id) %>%
+                    dplyr::select(flag_all_0_to_30), na.rm = TRUE))
 
   expect_true(all(result %>% dplyr::arrange(cohort_start_date, subject_id) %>%
-    dplyr::select(count_all_0_to_30) !=
-    cohort1 %>%
-      dplyr::arrange(cohort_start_date, subject_id) %>%
-      dplyr::select(count_all_0_to_30), na.rm = TRUE))
+                    dplyr::select(count_all_0_to_30) !=
+                    cohort1 %>%
+                    dplyr::arrange(cohort_start_date, subject_id) %>%
+                    dplyr::select(count_all_0_to_30), na.rm = TRUE))
 
   expect_true(all(result %>% dplyr::arrange(cohort_start_date, subject_id) %>%
-    dplyr::select(days_all_0_to_30) !=
-    cohort1 %>%
-      dplyr::arrange(cohort_start_date, subject_id) %>%
-      dplyr::select(days_all_0_to_30), na.rm = TRUE))
+                    dplyr::select(days_all_0_to_30) !=
+                    cohort1 %>%
+                    dplyr::arrange(cohort_start_date, subject_id) %>%
+                    dplyr::select(days_all_0_to_30), na.rm = TRUE))
 
   expect_true(all(result %>% dplyr::arrange(cohort_start_date, subject_id) %>%
-    dplyr::select(date_all_0_to_30) !=
-    cohort1 %>%
-      dplyr::arrange(cohort_start_date, subject_id) %>%
-      dplyr::select(date_all_0_to_30), na.rm = TRUE))
+                    dplyr::select(date_all_0_to_30) !=
+                    cohort1 %>%
+                    dplyr::arrange(cohort_start_date, subject_id) %>%
+                    dplyr::select(date_all_0_to_30), na.rm = TRUE))
 })
 
 test_that("overlapTable is empty, check return columns", {
@@ -996,7 +996,7 @@ test_that("overlapTable is empty, check return columns", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2, patient_size = 2)
 
 
   result <- cdm$cohort1 %>%
@@ -1076,7 +1076,7 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
     ),
   )
 
-  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2, patient_size = 3)
 
   compareNA <- function(v1, v2) {
     same <- (v1 == v2) | (is.na(v1) & is.na(v2))
@@ -1164,14 +1164,14 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
   expect_true(all(is.na(result$date_num1_m30_to_m1)))
 
   expect_error(cdm$cohort1 %>%
-    addCohortIntersectDate(
-      cdm = cdm,
-      targetCohortTable = "cohort2",
-      targetCohortId = c(1, 2, 3),
-      window = list(c(0, Inf), c(-30, -1))
-    ) %>%
-    dplyr::arrange(subject_id, cohort_start_date) %>%
-    dplyr::collect())
+                 addCohortIntersectDate(
+                   cdm = cdm,
+                   targetCohortTable = "cohort2",
+                   targetCohortId = c(1, 2, 3),
+                   window = list(c(0, Inf), c(-30, -1))
+                 ) %>%
+                 dplyr::arrange(subject_id, cohort_start_date) %>%
+                 dplyr::collect())
 
   result <- cdm$cohort1 %>%
     addCohortIntersectDate(
@@ -1195,3 +1195,16 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
   expect_true(all(is.na(result$cohort_1_m30_to_m1)))
   expect_true(all(is.na(result$cohort_1_0_to_inf)))
 })
+
+test_that("non snake columns not repeated in output", {
+  cdm <- mockPatientProfiles()
+  attr(cdm$cohort1, "cohort_set") <- attr(cdm$cohort1, "cohort_set") %>% dplyr::mutate(cohort_name = toupper(cohort_name))
+  cdm$cohort2 <- cdm$cohort2 %>%
+    addCohortIntersectFlag(cdm, "cohort1")
+
+  expect_true("cohort_1_0_to_inf" %in% colnames(cdm$cohort2))
+  expect_true("cohort_2_0_to_inf" %in% colnames(cdm$cohort2))
+  expect_false("COHORT_1_0_to_inf" %in% colnames(cdm$cohort2))
+  expect_false("COHORT_2_0_to_inf" %in% colnames(cdm$cohort2))
+
+})
